@@ -37,7 +37,7 @@ class ActivationTester(object):
             # locally we disable, so that contributors don't need to have everything setup
             try:
                 process = Popen(
-                    self._version_cmd, universal_newlines=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+                    self._version_cmd, universal_newlines=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
                 )
                 out, err = process.communicate()
                 result = out if out else err
@@ -144,16 +144,16 @@ class ActivationTester(object):
     def print_python_exe(self):
         return self.python_cmd(
             "import sys; print(sys.executable{})".format(
-                "" if six.PY3 or IS_PYPY else ".decode(sys.getfilesystemencoding())"
-            )
+                "" if six.PY3 or IS_PYPY else ".decode(sys.getfilesystemencoding())",
+            ),
         )
 
     def print_os_env_var(self, var):
         val = '"{}"'.format(var)
         return self.python_cmd(
             "import os; import sys; v = os.environ.get({}); print({})".format(
-                val, "v" if six.PY3 or IS_PYPY else "None if v is None else v.decode(sys.getfilesystemencoding())"
-            )
+                val, "v" if six.PY3 or IS_PYPY else "None if v is None else v.decode(sys.getfilesystemencoding())",
+            ),
         )
 
     def activate_call(self, script):
@@ -205,10 +205,13 @@ def raise_on_non_source_class():
     return RaiseOnNonSourceCall
 
 
-@pytest.fixture(scope="session")
-def activation_python(tmp_path_factory, special_char_name, current_fastest):
+@pytest.fixture(scope="session", params=[True, False], ids=["with_prompt", "no_prompt"])
+def activation_python(request, tmp_path_factory, special_char_name, current_fastest):
     dest = os.path.join(ensure_text(str(tmp_path_factory.mktemp("activation-tester-env"))), special_char_name)
-    session = cli_run(["--without-pip", dest, "--prompt", special_char_name, "--creator", current_fastest, "-vv"])
+    cmd = ["--without-pip", dest, "--creator", current_fastest, "-vv"]
+    if request.param:
+        cmd += ["--prompt", special_char_name]
+    session = cli_run(cmd)
     pydoc_test = session.creator.purelib / "pydoc_test.py"
     pydoc_test.write_text('"""This is pydoc_test.py"""')
     yield session
