@@ -1,7 +1,6 @@
 from __future__ import absolute_import, unicode_literals
 
 import itertools
-import os
 import sys
 from copy import copy
 
@@ -15,7 +14,7 @@ def test_bad_py_spec():
     spec = PythonSpec.from_string_spec(text)
     assert text in repr(spec)
     assert spec.str_spec == text
-    assert spec.path == os.path.abspath(text)
+    assert spec.path == text
     content = vars(spec)
     del content[str("str_spec")]
     del content[str("path")]
@@ -88,14 +87,14 @@ def test_version_satisfies_ok(req, spec):
 def _version_not_satisfies_pairs():
     target = set()
     version = tuple(str(i) for i in sys.version_info[0:3])
-    for i in range(len(version)):
-        req = ".".join(version[0 : i + 1])
-        for j in range(i + 1):
-            sat_ver = list(sys.version_info[0 : j + 1])
-            for l in range(j + 1):
+    for major in range(len(version)):
+        req = ".".join(version[0 : major + 1])
+        for minor in range(major + 1):
+            sat_ver = list(sys.version_info[0 : minor + 1])
+            for patch in range(minor + 1):
                 for o in [1, -1]:
                     temp = copy(sat_ver)
-                    temp[l] += o
+                    temp[patch] += o
                     sat = ".".join(str(i) for i in temp)
                     target.add((req, sat))
     return sorted(target)
@@ -112,4 +111,4 @@ def test_relative_spec(tmp_path, monkeypatch):
     monkeypatch.chdir(tmp_path)
     a_relative_path = str((tmp_path / "a" / "b").relative_to(tmp_path))
     spec = PythonSpec.from_string_spec(a_relative_path)
-    assert spec.path == os.path.abspath(str(tmp_path / a_relative_path))
+    assert spec.path == a_relative_path
